@@ -89,14 +89,18 @@ class Model:
     def register_element_by_path(self, path: str, generator, *args, **kwargs):
         ext = path.split('.')[-1]
         info = self.get_parser(ext).load_file(path, *args, **kwargs)
-        data = info.data
-        properties = info.properties
+        data = info.get('data', {})
+        properties = info.get('properties', {})
+        metadata = info.get('metadata', {})
 
         # Prioritize kwargs over file properties (useful in CLI)
         kwargs['data'] = kwargs.get('data', data)
         for k, v in properties.items():
             kwargs[k] = kwargs.get(k, v)
 
+        for k, v in metadata.items():
+            kwargs[k] = kwargs.get(k, v)
+
         return self.register_element(generator(*args, **kwargs))
 
     """
@@ -148,17 +152,18 @@ class Model:
     def delete(self, _id: int) -> None:
         self.element_collection.delete(_id)
 
+    def clear(self) -> None:
+        self.element_collection.clear()
+
     """
     Element exporting
     """
     def export(self, path: str, _id: int) -> None:
-        element = self.get(_id)
         ext = path.split('.')[-1]
+        element = self.get(_id)
 
         data = element.data
-        properties = {}
-        for k in element.exportable_properties:
-            properties[k] = getattr(element, k)
+        properties = element.properties
 
         self.get_parser(ext).save_file(path=path, data=data, properties=properties)
 
