@@ -31,7 +31,7 @@ class MainWindow(QMainWindow):
         uic.loadUi(f'{pathlib.Path(__file__).parent}/UI/mainwindow.ui', self)
         self.resize(1000, 620)
 
-        self.setWindowTitle('BlastSight')
+        self.setWindowTitle('BlastSightDM')
         self.setWindowIcon(IconCollection.get('blastsight.png'))
         self.toolbar.setWindowTitle('Toolbar')
 
@@ -84,7 +84,7 @@ class MainWindow(QMainWindow):
             }
         }
 
-        self.settings = QSettings('BlastSight', application='blastsight', parent=self)
+        self.settings = QSettings('BlastSightDM', application='blastsight-dm', parent=self)
 
         # Progress bar (hidden by default)
         self.progress_bar = QProgressBar(self.statusBar)
@@ -110,15 +110,12 @@ class MainWindow(QMainWindow):
             actions.action_autorotate.trigger()
 
         # Set animated as True when starting the app
-        if not actions.action_animate.isChecked():
-            actions.action_animate.trigger()
+        if not actions.action_animated.isChecked():
+            actions.action_animated.trigger()
 
         # Set camera widget as hidden
         self.dockWidget_camera.hide()
 
-        # self.title = self.windowTitle()
-        # self.viewer.signal_fps_updated.connect(lambda x: self.setWindowTitle(f'{self.title} (FPS: {x:.1f})'))
-
     def generate_menubar(self) -> None:
         actions = self.toolbar.action_collection
 
@@ -152,15 +149,16 @@ class MainWindow(QMainWindow):
         # Tools
         self.menu_Tools.addAction(actions.action_slice_meshes)
         self.menu_Tools.addAction(actions.action_slice_blocks)
-        self.menu_Tools.addAction(actions.action_detection_mode)
-        self.menu_Tools.addAction(actions.action_measurement_mode)
+        self.menu_Tools.addAction(actions.action_detection_controller)
+        self.menu_Tools.addAction(actions.action_measurement_controller)
         self.menu_Tools.addSeparator()
-        self.menu_Tools.addAction(actions.action_normal_mode)
-        self.menu_Tools.addAction(actions.action_cross_section)
+        self.menu_Tools.addAction(actions.action_normal_controller)
+        # FIXME Removed until further notice
+        # self.menu_Tools.addAction(actions.action_cross_section)
 
         # Settings
         self.menu_Settings.addAction(actions.action_autofit)
-        self.menu_Settings.addAction(actions.action_animate)
+        self.menu_Settings.addAction(actions.action_animated)
         self.menu_Settings.addAction(actions.action_autorotate)
         self.menu_Settings.addAction(actions.action_turbo_rendering)
 
@@ -200,10 +198,10 @@ class MainWindow(QMainWindow):
         # Tools
         actions.action_slice_meshes.triggered.connect(self.slot_slice_meshes)
         actions.action_slice_blocks.triggered.connect(self.slot_slice_blocks)
-        actions.action_detection_mode.triggered.connect(self.slot_detection_mode)
-        actions.action_measurement_mode.triggered.connect(self.slot_measurement_mode)
+        actions.action_detection_controller.triggered.connect(self.slot_detection_controller)
+        actions.action_measurement_controller.triggered.connect(self.slot_measurement_controller)
 
-        actions.action_normal_mode.triggered.connect(self.slot_normal_mode)
+        actions.action_normal_controller.triggered.connect(self.slot_normal_controller)
         actions.action_cross_section.triggered.connect(self.slot_cross_section)
 
         # Help
@@ -212,7 +210,7 @@ class MainWindow(QMainWindow):
 
         # Viewer signals
         self.viewer.signal_fps_updated.connect(self.print_fps)
-        self.viewer.signal_mode_updated.connect(self.slot_mode_updated)
+        self.viewer.signal_controller_updated.connect(self.slot_controller_updated)
         self.viewer.signal_elements_detected.connect(self.slot_elements_detected)
         self.viewer.signal_mesh_distances.connect(self.slot_mesh_distances)
 
@@ -256,8 +254,8 @@ class MainWindow(QMainWindow):
     def slot_element_export_failure(self) -> None:
         self.statusBar.showMessage(f'Failed to export.')
 
-    def slot_mode_updated(self, mode: str) -> None:
-        self.statusBar.showMessage(f'Mode: {mode}')
+    def slot_controller_updated(self, name: str) -> None:
+        self.statusBar.showMessage(f'Controller: {name}')
 
     def slot_mesh_distances(self, distance_dict: dict) -> None:
         self.statusBar.showMessage(f'Distance: {distance_dict.get("distance")}')
@@ -298,10 +296,10 @@ class MainWindow(QMainWindow):
                 self.handle_slices(description, executer_standard)
 
             # Disconnect
-            self.viewer.set_normal_mode()
+            self.viewer.set_normal_controller()
             self.viewer.signal_slice_description.disconnect()
 
-        self.viewer.set_slice_mode()
+        self.viewer.set_slice_controller()
         self.viewer.signal_slice_description.connect(handler)
 
     def slot_slice_blocks(self) -> None:
@@ -313,10 +311,10 @@ class MainWindow(QMainWindow):
             self.handle_slices(description, executer)
 
             # Disconnect
-            self.viewer.set_normal_mode()
+            self.viewer.set_normal_controller()
             self.viewer.signal_slice_description.disconnect()
 
-        self.viewer.set_slice_mode()
+        self.viewer.set_slice_controller()
         self.viewer.signal_slice_description.connect(handler)
 
     def slot_cross_section(self, status: bool) -> None:
@@ -386,7 +384,9 @@ class MainWindow(QMainWindow):
             directory=self.last_dir,
             filter=self.filters_dict.get(hint).get('load'))
 
-        path_list = sorted([p for p in paths if p != ''])
+        # If path == '', then bool(path) is False
+        path_list = sorted(filter(bool, paths))
+
         if len(path_list) > 0:
             self.statusBar.showMessage(f'Loading {len(path_list)} element(s)...')
             self._thread_runner(self.viewer.load_multiple, path_list, loader, *args, **kwargs)
@@ -469,7 +469,8 @@ class MainWindow(QMainWindow):
         proposed_path = QDir(self.last_dir).filePath(element.name)
 
         # TODO Check hints by element type
-        filters = 'BlastSight FIXME (*.h5m);;'
+        filters = 'BlastSight Mesh (*.h5m);;'\
+                  'BlastSight Blocks/Points (*.h5p);;'
 
         (path, selected_filter) = QFileDialog.getSaveFileName(
             parent=self,
@@ -482,16 +483,16 @@ class MainWindow(QMainWindow):
             self._thread_runner(self.viewer.export_element, path, _id)
 
     """
-    Slots for modifying interaction modes
+    Slots for modifying interaction controllers
     """
-    def slot_normal_mode(self) -> None:
-        self.viewer.set_normal_mode()
+    def slot_normal_controller(self) -> None:
+        self.viewer.set_normal_controller()
 
-    def slot_detection_mode(self) -> None:
-        self.viewer.set_detection_mode()
+    def slot_detection_controller(self) -> None:
+        self.viewer.set_detection_controller()
 
-    def slot_measurement_mode(self) -> None:
-        self.viewer.set_measurement_mode()
+    def slot_measurement_controller(self) -> None:
+        self.viewer.set_measurement_controller()
 
     """
     Slots for showing help/about dialogs
