@@ -36,11 +36,11 @@ from .drawables.tubegl import TubeGL
 from .drawablefactory import DrawableFactory
 from .fpscounter import FPSCounter
 
-from ..controller.mode import Mode
-from ..controller.detectionmode import DetectionMode
-from ..controller.normalmode import NormalMode
-from ..controller.slicemode import SliceMode
-from ..controller.measurementmode import MeasurementMode
+from ..controller.basecontroller import BaseController
+from ..controller.detectioncontroller import DetectionController
+from ..controller.normalcontroller import NormalController
+from ..controller.slicecontroller import SliceController
+from ..controller.measurementcontroller import MeasurementController
 
 from ..model import utils
 from ..model.model import Model
@@ -71,7 +71,7 @@ class IntegrableViewer(QOpenGLWidget):
 
     signal_screen_clicked = Signal(object)
     signal_fps_updated = Signal(float)
-    signal_mode_updated = Signal(str)
+    signal_controller_updated = Signal(str)
     signal_projection_updated = Signal(str)
 
     signal_camera_rotated = Signal(object)
@@ -94,7 +94,7 @@ class IntegrableViewer(QOpenGLWidget):
         self.drawable_collection = GLDrawableCollection(self)
 
         # Controllers
-        self.current_mode = None
+        self.current_controller = None
         self.controllers = {}
 
         # Camera/World/Projection
@@ -106,18 +106,15 @@ class IntegrableViewer(QOpenGLWidget):
         self.fps_counter = FPSCounter()
 
         # Initial positions and rotations
-        self.rotation_center = [0.0, 0.0, 0.0]
-        self.rotation_angle = [0.0, 0.0, 0.0]
-        self.camera_position = [0.0, 0.0, 200.0]
+        self._rotation_center = np.array([0.0, 0.0, 0.0])
+        self._rotation_angle = np.array([0.0, 0.0, 0.0])
+        self._camera_position = np.array([0.0, 0.0, 200.0])
 
         # Extra information
-        self._turbo = False
-        self._autofit = False
-        self._animated = False
-
+        self.is_animated = False
         self.fov = 45.0
         self.smoothness = 2.0  # Bigger => smoother (but slower) rotations
-        self.projection_mode = 'Perspective'  # 'Perspective'/'Prthographic'
+        self.current_projection = 'Perspective'  # 'Perspective'/'Orthographic'
 
         # Initialize viewer
         self.initialize()
@@ -134,11 +131,11 @@ class IntegrableViewer(QOpenGLWidget):
         self.signal_center_translated.connect(self.update)
 
         # Controllers
-        self.add_controller(NormalMode(self))
-        self.add_controller(DetectionMode(self))
-        self.add_controller(SliceMode(self))
-        self.add_controller(MeasurementMode(self))
-        self.set_normal_mode()
+        self.add_controller(NormalController(self))
+        self.add_controller(DetectionController(self))
+        self.add_controller(SliceController(self))
+        self.add_controller(MeasurementController(self))
+        self.set_normal_controller()
 
         # FPSCounter
         self.fps_counter.add_callback(self.signal_fps_updated.emit)
@@ -171,29 +168,29 @@ class IntegrableViewer(QOpenGLWidget):
     """
     @property
     def camera_position(self) -> np.ndarray:
-        return np.array([self.xCameraPos, self.yCameraPos, self.zCameraPos])
+        return self._camera_position
 
     @property
     def rotation_angle(self) -> np.ndarray:
-        return np.array([self.xCenterRot, self.yCenterRot, self.zCenterRot])
+        return self._rotation_angle
 
     @property
     def rotation_center(self) -> np.ndarray:
-        return np.array([self.xCenterPos, self.yCenterPos, self.zCenterPos])
+        return self._rotation_center
 
     @camera_position.setter
     def camera_position(self, pos: list) -> None:
-        self.xCameraPos, self.yCameraPos, self.zCameraPos = pos
+        self._camera_position = np.asarray(pos)
         self.signal_camera_translated.emit(pos)
 
     @rotation_angle.setter
     def rotation_angle(self, rot: list) -> None:
-        self.xCenterRot, self.yCenterRot, self.zCenterRot = rot
+        self._rotation_angle = np.asarray(rot)
         self.signal_camera_rotated.emit(rot)
 
     @rotation_center.setter
     def rotation_center(self, center: list) -> None:
-        self.xCenterPos, self.yCenterPos, self.zCenterPos = center
+        self._rotation_center = np.asarray(center)
         self.signal_center_translated.emit(center)
 
     """
@@ -226,14 +223,14 @@ class IntegrableViewer(QOpenGLWidget):
 
         def setter(value):
             self.camera_position = value
-        self.animate(origin, target, method=setter) if self.is_animated() else setter(target)
+        self.animate(origin, target, method=setter) if self.is_animated else setter(target)
 
     def set_rotation_center(self, target) -> None:
         origin = self.get_rotation_center()
 
         def setter(value):
             self.rotation_center = value
-        self.animate(origin, target, method=setter) if self.is_animated() else setter(target)
+        self.animate(origin, target, method=setter) if self.is_animated else setter(target)
 
     def set_rotation_angle(self, target) -> None:
         # Fix any difference > 180° so the camera doesn't over-rotate
@@ -243,7 +240,7 @@ class IntegrableViewer(QOpenGLWidget):
 
         def setter(value):
             self.rotation_angle = value
-        self.animate(origin, target, method=setter) if self.is_animated() else setter(target)
+        self.animate(origin, target, method=setter) if self.is_animated else setter(target)
 
     """
     Animation / Turbo
@@ -257,11 +254,8 @@ class IntegrableViewer(QOpenGLWidget):
         self.blockSignals(False)
         self.recreate()
 
-    def is_animated(self) -> bool:
-        return self._animated
-
     def set_animated(self, status: bool) -> None:
-        self._animated = status
+        self.is_animated = status
 
     def animate(self, start, end, method: callable, **kwargs) -> callable:
         milliseconds = int(kwargs.get('milliseconds', 300))
@@ -296,13 +290,13 @@ class IntegrableViewer(QOpenGLWidget):
     Projections
     """
     def perspective_projection(self) -> None:
-        self.projection_mode = 'Perspective'
-        self.signal_projection_updated.emit(self.projection_mode)
+        self.current_projection = 'Perspective'
+        self.signal_projection_updated.emit(self.current_projection)
         self.update()
 
     def orthographic_projection(self) -> None:
-        self.projection_mode = 'Orthographic'
-        self.signal_projection_updated.emit(self.projection_mode)
+        self.current_projection = 'Orthographic'
+        self.signal_projection_updated.emit(self.current_projection)
         self.update()
 
     """
@@ -457,9 +451,8 @@ class IntegrableViewer(QOpenGLWidget):
 
     def clear(self) -> None:
         self.makeCurrent()
-        for _id in self.get_all_ids():
-            self.model.delete(_id)
-            self.drawable_collection.delete(_id)
+        self.model.clear()
+        self.drawable_collection.clear()
         self.signal_file_modified.emit()
 
     """
@@ -511,7 +504,7 @@ class IntegrableViewer(QOpenGLWidget):
         fov_rad = self.fov * np.pi / 180.0
 
         # In perspective projection, we need a clever trigonometric calculation.
-        if self.projection_mode == 'Perspective':
+        if self.current_projection == 'Perspective':
             dist = (md / np.tan(fov_rad / 2) + md) / 2.0
             z_shift = dist * max(1.0, 1.0 / aspect)
 
@@ -574,9 +567,9 @@ class IntegrableViewer(QOpenGLWidget):
         self.world.translate(*self.rotation_center)
 
         # Allow rotation of the world
-        self.world.rotate(self.xCenterRot, 1.0, 0.0, 0.0)
-        self.world.rotate(self.yCenterRot, 0.0, 1.0, 0.0)
-        self.world.rotate(self.zCenterRot, 0.0, 0.0, 1.0)
+        self.world.rotate(self.rotation_angle[0], 1.0, 0.0, 0.0)
+        self.world.rotate(self.rotation_angle[1], 0.0, 1.0, 0.0)
+        self.world.rotate(self.rotation_angle[2], 0.0, 0.0, 1.0)
 
         # Restore world
         self.world.translate(*-self.rotation_center)
@@ -604,9 +597,9 @@ class IntegrableViewer(QOpenGLWidget):
     def resizeGL(self, w: float, h: float) -> None:
         aspect = w / h
 
-        if self.projection_mode == 'Perspective':
+        if self.current_projection == 'Perspective':
             self.proj.perspective(self.fov, aspect, 1.0, 100000.0)
-        else:  # if self.projection_mode == 'Orthographic':
+        else:  # if self.current_projection == 'Orthographic':
             z = self.off_center[2]
             self.proj.ortho(-z, z, -z / aspect, z / aspect, 0.0, 100000.0)
 
@@ -667,7 +660,7 @@ class IntegrableViewer(QOpenGLWidget):
         def orthographic_ray() -> np.ndarray:
             return self.unproject(0.0, 0.0, 0.0)
 
-        if self.projection_mode == 'Perspective':
+        if self.current_projection == 'Perspective':
             return perspective_ray()
 
         return orthographic_ray()
@@ -701,7 +694,7 @@ class IntegrableViewer(QOpenGLWidget):
 
             return origin
 
-        if self.projection_mode == 'Perspective':
+        if self.current_projection == 'Perspective':
             return perspective_origin()
 
         return orthographic_origin()
@@ -716,7 +709,7 @@ class IntegrableViewer(QOpenGLWidget):
             origin_diff = np.diff(origin_list, axis=0)[0]
             return utils.normalize(np.cross(ray_list[0], origin_diff))
 
-        if self.projection_mode == 'Perspective':
+        if self.current_projection == 'Perspective':
             return perspective_normal()
 
         return orthographic_normal()
@@ -730,8 +723,24 @@ class IntegrableViewer(QOpenGLWidget):
         rotmat = QQuaternion.fromDirection(QVector3D(*normal), QVector3D(*up)).toRotationMatrix().data()
         return Rotation.from_matrix(np.array(rotmat).reshape((3, 3))).as_euler('XYZ', degrees=True)
 
-    def set_camera_from_vectors(self, normal: np.ndarray, up: np.ndarray) -> None:
+    def set_camera_from_vectors(self, normal: np.ndarray, up: np.ndarray, as_axis: bool = True) -> None:
         # Auto-moves the camera using the normal as direction
+
+        def best_projection() -> np.ndarray:
+            # We will alter the 'up' vector, projecting it onto each of the axes.
+            # The longest projection will be used instead of the 'up' vector.
+            candidates = np.identity(3)
+            lengths = np.abs(utils.dot_by_row(candidates, np.tile(up, (3, 1))))
+            return utils.normalize(candidates[np.argmax(lengths)])
+
+        if as_axis:
+            # For now, we'll use the best Z projection
+            # If the dot-product fails (highly improbable), we'll use the Y projection.
+            if np.dot([0.0, 0.0, 1.0], up) > 1e-6:
+                up = np.array([0.0, 0.0, 1.0])
+            else:
+                up = np.array([0.0, 1.0, 0.0])
+
         self.set_rotation_angle(self.angles_from_vectors(normal, up))
 
     def generate_slice_description(self, origin_list: list, ray_list: list) -> None:
@@ -798,47 +807,55 @@ class IntegrableViewer(QOpenGLWidget):
     """
     Controller
     """
-    def add_controller(self, controller: Mode) -> None:
+    def add_controller(self, controller: BaseController) -> None:
         self.controllers[controller.name] = controller
 
-    def set_controller(self, mode_name: str) -> None:
-        self.current_mode = self.controllers.get(mode_name)
-        self.signal_mode_updated.emit(self.current_mode.name)
+    def set_controller(self, name: str) -> None:
+        self.current_controller = self.controllers.get(name)
+        self.signal_controller_updated.emit(name)
         self.update()
 
-    def set_normal_mode(self) -> None:
+    def set_normal_controller(self) -> None:
         self.set_controller('Normal')
 
-    def set_detection_mode(self) -> None:
+    def set_detection_controller(self) -> None:
         self.set_controller('Detection')
 
-    def set_slice_mode(self) -> None:
+    def set_slice_controller(self) -> None:
         self.set_controller('Slice')
 
-    def set_measurement_mode(self) -> None:
+    def set_measurement_controller(self) -> None:
         self.set_controller('Measurement')
 
     """
     Events (dependent on current controller)
     """
     def mouseMoveEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mouseMoveEvent(event)
+        self.current_controller.mouseMoveEvent(event)
         self.update()
 
     def mousePressEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mousePressEvent(event)
+        self.current_controller.mousePressEvent(event)
         self.update()
 
     def mouseDoubleClickEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mouseDoubleClickEvent(event)
+        self.current_controller.mouseDoubleClickEvent(event)
         self.update()
 
     def mouseReleaseEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mouseReleaseEvent(event)
+        self.current_controller.mouseReleaseEvent(event)
+        self.update()
+
+    def keyPressEvent(self, event, *args, **kwargs) -> None:
+        self.current_controller.keyPressEvent(event)
+        self.update()
+
+    def keyReleaseEvent(self, event, *args, **kwargs) -> None:
+        self.current_controller.keyReleaseEvent(event)
         self.update()
 
     def wheelEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.wheelEvent(event)
+        self.current_controller.wheelEvent(event)
         self.update()
 
     def dragEnterEvent(self, event, *args, **kwargs) -> None:
